@@ -73,30 +73,13 @@ namespace Ogre {
 
         void updateFromParentImpl(void) const;
 
-        /** See Node. */
-        Node* createChildImpl(void);
-
-        /** See Node. */
-        Node* createChildImpl(const String& name);
-
         /** See Node */
         void setParent(Node* parent);
 
-        /** Internal method for setting whether the node is in the scene 
-            graph.
-        */
-        virtual void setInSceneGraph(bool inGraph);
-
         /// Auto tracking target
         SceneNode* mAutoTrackTarget;
         /// Pointer to a Wire Bounding Box for this Node
         std::unique_ptr<WireBoundingBox> mWireBoundingBox;
-        /// Tracking offset for fine tuning
-        Vector3 mAutoTrackOffset;
-        /// Local 'normal' direction vector
-        Vector3 mAutoTrackLocalDirection;
-        /// Fixed axis to yaw around
-        Vector3 mYawFixedAxis;
 
         /** Index in the vector holding this node reference. Used for O(1) removals.
 
@@ -105,13 +88,31 @@ namespace Ogre {
         */
         size_t mGlobalIndex;
 
+        /// Tracking offset for fine tuning
+        Vector3 mAutoTrackOffset;
+        /// Local 'normal' direction vector
+        Vector3 mAutoTrackLocalDirection;
+        /// Fixed axis to yaw around
+        Vector3 mYawFixedAxis;
+
         /// Whether to yaw around a fixed axis.
         bool mYawFixed : 1;
         /// Is this node a current part of the scene graph?
         bool mIsInSceneGraph : 1;
+    protected: // private in 1.13
         /// Flag that determines if the bounding box of the node should be displayed
         bool mShowBoundingBox : 1;
         bool mHideBoundingBox : 1;
+
+        /** Internal method for setting whether the node is in the scene
+            graph.
+        */
+        virtual void setInSceneGraph(bool inGraph);
+        /** See Node. */
+        Node* createChildImpl(void);
+
+        /** See Node. */
+        Node* createChildImpl(const String& name);
     public:
         /** Constructor, only to be called by the creator SceneManager.
         @remarks
@@ -212,6 +213,7 @@ namespace Ogre {
             @param
                 displayNodes If true, the nodes themselves are rendered as a set of 3 axes as well
                     as the objects being rendered. For debugging purposes.
+            @param onlyShadowCasters
         */
         void _findVisibleObjects(Camera* cam, RenderQueue* queue,
             VisibleObjectsBoundsInfo* visibleBounds, 
@@ -408,11 +410,11 @@ namespace Ogre {
             const Vector3& localDirectionVector = Vector3::NEGATIVE_UNIT_Z,
             const Vector3& offset = Vector3::ZERO);
         /** Get the auto tracking target for this node, if any. */
-        SceneNode* getAutoTrackTarget(void) { return mAutoTrackTarget; }
+        SceneNode* getAutoTrackTarget(void) const { return mAutoTrackTarget; }
         /** Get the auto tracking offset for this node, if the node is auto tracking. */
-        const Vector3& getAutoTrackOffset(void) { return mAutoTrackOffset; }
+        const Vector3& getAutoTrackOffset(void) const { return mAutoTrackOffset; }
         /** Get the auto tracking local direction for this node, if it is auto tracking. */
-        const Vector3& getAutoTrackLocalDirection(void) { return mAutoTrackLocalDirection; }
+        const Vector3& getAutoTrackLocalDirection(void) const { return mAutoTrackLocalDirection; }
         /** Internal method used by OGRE to update auto-tracking cameras. */
         void _autoTrack(void);
         /** Gets the parent of this SceneNode. */
@@ -425,7 +427,7 @@ namespace Ogre {
         @param visible Whether the objects are to be made visible or invisible
         @param cascade If true, this setting cascades into child nodes too.
         */
-        void setVisible(bool visible, bool cascade = true);
+        void setVisible(bool visible, bool cascade = true) const;
         /** Inverts the visibility of all objects attached to this node.
         @remarks    
         This is a shortcut to calling setVisible(!isVisible()) on the objects attached
@@ -433,7 +435,7 @@ namespace Ogre {
         nodes. 
         @param cascade If true, this setting cascades into child nodes too.
         */
-        void flipVisibility(bool cascade = true);
+        void flipVisibility(bool cascade = true) const;
 
         /** Tells all objects attached to this node whether to display their
             debug information or not.
@@ -444,7 +446,7 @@ namespace Ogre {
         @param enabled Whether the objects are to display debug info or not
         @param cascade If true, this setting cascades into child nodes too.
         */
-        void setDebugDisplayEnabled(bool enabled, bool cascade = true);
+        void setDebugDisplayEnabled(bool enabled, bool cascade = true) const;
 
         /// As Node::getDebugRenderable, except scaling is automatically determined
         DebugRenderable* getDebugRenderable();
